@@ -2,6 +2,8 @@ import os
 from pathlib import Path
 from .interaction import BaseInteraction
 from .tokens import TokenManager, FileTokensStorage
+import logging
+logger = logging.getLogger(__name__)
 
 # load token manager
 token_path = Path.cwd().resolve()
