@@ -3,8 +3,6 @@ import time
 from typing import Tuple
 from requests import Session
 from requests import ConnectionError
-from requests import request
-
 from .exceptions import *
 from .filters import Filter
 
@@ -76,10 +74,13 @@ class BaseInteraction:
             else:
                 if response.status_code == 200:
                     return response, 200
-                if response.status_code == 204:
+                elif response.status_code == 204:
                     return None, 204
-                if response.status_code < 300 or response.status_code == 400:
+                elif response.status_code < 300 or response.status_code == 400:
                     return response.json(), response.status_code
+                else:
+                    logger.error("There is a error with this request.")
+                    logger.error("Status: {} ({})".format(response.status_code, response.text))
                 if response.status_code == 401:
                     raise UnAuthorizedException()
                 if response.status_code == 403:
