@@ -117,14 +117,17 @@ class TokenManager:
         try:
             response = requests.post("https://{}.amocrm.ru/oauth2/access_token".format(self.subdomain), json=data)
         except requests.exceptions.RequestException:
-
             if not skip_error:
                 raise
         else:
+            if response.status_code != 200:
+                logger.warning('Not possible create new token. Maybe there already there?')
+                logger.warning(f"Status code: {response.status_code}: "
+                               f"{response.json()['title']} {response.json()['hint']}")
+                logger.warning(f"The request data was:\n{str(data)}")
             if response.status_code != 200 and not skip_error:
-                raise Exception(response.json()["title"])
+                raise Exception(response.json()["title"] + response.json()["hint"])
             if response.status_code != 200 and skip_error:
-                logger.info("Can not init the token. If you lucky, you already have a working one.")
                 return
             response = response.json()
             self._storage.save_tokens(response["access_token"], response["refresh_token"])
